==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/sites/lang/sites_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'La sindicacion a pas capitat: lo backend indicat es indeschifrable ò prepaua minga d’article.',
	'avis_echec_syndication_02' => 'La sindicacion a pas capitat: impossible d’accedir au backend d’aqueu sit.',
	'avis_site_introuvable' => 'Sit introbable',
	'avis_site_syndique_probleme' => 'Atencion : la sindicacion d’aqueu sit a encontrat un problema ; lo sistema es doncas temporarament interromput per aüra. Verificatz l’adreça dau fichier de sindicacion d’aqueu sit (<b>@url_syndic@</b>), e provatz mai una recuperacion dei informacions.',
	'avis_sites_probleme_syndication' => 'Aquelu sits an encontrat un problema de sindicacion',
	'avis_sites_syndiques_probleme' => 'Aquelu sits sindicats an pauat un problema',

	// B
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion à priòri',
	'bouton_radio_non_syndication' => 'Minga de sindicacion', # essai commentaire
	'bouton_radio_syndication' => 'Sindicacion:',

	// E
	'entree_adresse_fichier_syndication' => 'Adreça dau fichier de sindicacion:',
	'entree_adresse_site' => '<b>Adreça dau sit</b> [Obligatòri]',
	'entree_description_site' => 'Descripcion dau sit',

	// F
	'form_prop_nom_site' => 'Nom dau sit',

	// I
	'icone_modifier_site' => 'Modificar aqueu sit',
	'icone_referencer_nouveau_site' => 'Referençar un novèu sit',
	'icone_voir_sites_references' => 'Veire lu sits referençats',
	'info_1_site' => '1 sit',
	'info_a_valider' => '[de validar]',
	'info_bloquer' => 'blocar',
	'info_bloquer_lien' => 'Blocar aquel estac',
	'info_derniere_syndication' => 'La darriera sindicacion d’aqueu sit si faguèt lo',
	'info_liens_syndiques_1' => 'estacs sindicats',
	'info_liens_syndiques_2' => 'son en aspèra de validacion.',
	'info_nom_site_2' => '<b>Nom dau sit</b> [Obligatòri]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'problèma de',
	'info_question_proposer_site' => 'Cu pòu prepauar de sits referençats?',
	'info_retablir_lien' => 'Tornar establir aquel estac',
	'info_site_attente' => 'Sit web en aspèra de validacion',
	'info_site_propose' => 'Sit prepauat lo :',
	'info_site_reference' => 'Sit referençat en linha',
	'info_site_refuse' => 'Sit web refudat',
	'info_site_syndique' => 'Aqueu sit es sindicat...',
	'info_site_valider' => 'Sits de validar',
	'info_sites_referencer' => 'Referençar un sit',
	'info_sites_refuses' => 'Lu sits refudats',
	'info_statut_site_1' => 'Aqueu sit es :',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Prepauat',
	'info_statut_site_4' => 'Ai rementa',
	'info_syndication' => 'sindicacion:',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Blocar lu estacs sindicats per validacion',
	'item_gerer_annuaire_site_web' => 'Gerar un annuari de sits web',
	'item_non_bloquer_liens_syndiques' => 'Blocar pas lu ligams eissuts de la sindicacion',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l’annuari de sits web',
	'item_non_utiliser_syndication' => 'Utilisar pas la sindicacion automatica',
	'item_utiliser_syndication' => 'Utilisar la sindicacion automatica',

	// L
	'lien_mise_a_jour_syndication' => 'Actualisar aüra',
	'lien_nouvelle_recuperation' => 'Temptar una novèla recuperacion de li donadas',

	// S
	'syndic_choix_moderation' => 'Que faire dei estacs venentsen provenença d’aquèu sit ?',
	'syndic_choix_oublier' => 'Que faire dei estacs que figuran pas plus dins lo fichièr de syndicacion ?',
	'syndic_choix_resume' => 'Certen sites difusan lo tèxt complet dei articles. Quora aqueste es disponible, desiratz de lo sindicar? :',
	'syndic_lien_obsolete' => 'Estac vielh',
	'syndic_option_miroir' => 'li blocar automaticament',
	'syndic_option_oubli' => 'li efaçar (après @mois@ mes)',
	'syndic_option_resume_non' => 'lo contengut complet dei articles (au format HTML)',
	'syndic_option_resume_oui' => 'un simple resumit (au format tèxte)',
	'syndic_options' => 'Opcions de syndicacion :',

	// T
	'texte_liens_sites_syndiques' => 'Lu ligams eissits dei sits sindicats si poadon
   blocar à priòri; lo reglatge
  çai sota indica lo reglatge predefinit dei
   sits sindicats après la sieu creacion. De tota maniera,
    es possible pi de 
   desblocar cada ligam individualament, ò de
   chausir, sit per sit, de blocar lu ligams avenidors
   de tau ò tau sit.', # MODIF
	'texte_messages_publics' => 'Messatges publics de l’article:',
	'texte_non_fonction_referencement' => 'Podètz chausir d’utilisar pas aquela foncion automatica, e indicar de vos meme lu elements que tòcan aqueu sit...', # MODIF
	'texte_referencement_automatique' => '<b>Referençament automatisat d’un sit</b><br />Podètz referençar leu un sit web en indicant çai sota l’adreça URL desirada, ò l’adreça dau sieu fichier de sindicacion. SPIP agantarà automaticament li informacions que concernisson aqueu sit (titre, descripcion...).', # MODIF
	'texte_syndication' => 'Si pòu recuperar automaticament, quora un sit web lo permet, 
  la tièra dei sieus noveutats. Per far aquò, vos cau activar la sindicacion. 
  <blockquote><i>D’unu aubergadors activon pas aquela foncionalitat; 
  dins aqueu cas, podretz pas utilisar la sindicacion de contengut
  despí lo voastre sit.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Articles sindicats tirats d’aqueu sit',
	'titre_dernier_article_syndique' => 'Darriers articles sindicats',
	'titre_page_sites_tous' => 'Lu sits referençats',
	'titre_referencement_sites' => 'Referençament de sits e sindicacion',
	'titre_site_numero' => 'SIT NÚMERO :',
	'titre_sites_proposes' => 'Lu sits prepauats',
	'titre_sites_references_rubrique' => 'Lu sits referençats dins aquela rubrica',
	'titre_sites_syndiques' => 'Lu sits sindicats',
	'titre_sites_tous' => 'Lu sits referençats',
	'titre_syndication' => 'Sindicacion dei sits'
);

?>

==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/sites/lang/sites_oc_ni.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/sites?lang_cible=oc_ni
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_echec_syndication_01' => 'La sindicacion a pas capitat: lo backend indicat es indeschifrable ò prepaua minga d’article.',
	'avis_echec_syndication_02' => 'La sindicacion a pas capitat: impossible d’accedir au backend d’aqueu sit.',
	'avis_site_introuvable' => 'Sit introbable',
	'avis_site_syndique_probleme' => 'Atencion : la sindicacion d’aqueu sit a encontrat un problema ; lo sistema es doncas temporarament interromput per aüra. Verificatz l’adreça dau fichier de sindicacion d’aqueu sit (<b>@url_syndic@</b>), e provatz mai una recuperacion dei informacions.',
	'avis_sites_probleme_syndication' => 'Aquelu sits an encontrat un problema de sindicacion',
	'avis_sites_syndiques_probleme' => 'Aquelu sits sindicats an pauat un problema',

	// B
	'bouton_radio_modere_posteriori' => 'moderacion à posteriòri', # MODIF
	'bouton_radio_modere_priori' => 'moderacion à priòri', # MODIF
	'bouton_radio_non_syndication' => 'Minga de sindicacion', # essai commentaire
	'bouton_radio_syndication' => 'Sindicacion:',

	// E
	'entree_adresse_fichier_syndication' => 'Adreça dau fichier de sindicacion:',
	'entree_adresse_site' => '<b>Adreça dau sit</b> [Obligatòri]',
	'entree_description_site' => 'Descripcion dau sit',

	// F
	'form_prop_nom_site' => 'Nom dau sit',

	// I
	'icone_modifier_site' => 'Modificar aqueu sit',
	'icone_referencer_nouveau_site' => 'Referençar un novèu sit',
	'icone_voir_sites_references' => 'Veire lu sits referençats',
	'info_a_valider' => '[de validar]',
	'info_bloquer' => 'blocar',
	'info_bloquer_lien' => 'Blocar aquel estac',
	'info_derniere_syndication' => 'La darriera sindicacion d’aqueu sit si faguèt lo',
	'info_liens_syndiques_1' => 'estacs sindicats',
	'info_liens_syndiques_2' => 'son en aspèra de validacion.',
	'info_nom_site_2' => '<b>Nom dau sit</b> [Obligatòri]',
	'info_panne_site_syndique' => 'Sit sindicat en pana',
	'info_probleme_grave' => 'problèma de',
	'info_question_proposer_site' => 'Cu pòu prepauar de sits referençats?',
	'info_retablir_lien' => 'Tornar establir aquel estac',
	'info_site_attente' => 'Sit web en aspèra de validacion',
	'info_site_propose' => 'Sit prepauat lo :',
	'info_site_reference' => 'Sit referençat en linha',
	'info_site_refuse' => 'Sit web refudat',
	'info_site_syndique' => 'Aqueu sit es sindicat...', # MODIF
	'info_site_valider' => 'Sits de validar',
	'info_sites_referencer' => 'Referençar un sit',
	'info_sites_refuses' => 'Lu sits refudats',
	'info_statut_site_1' => 'Aqueu sit es :',
	'info_statut_site_2' => 'Publicat',
	'info_statut_site_3' => 'Prepauat',
	'info_statut_site_4' => 'Au bordilhier', # MODIF
	'info_syndication' => 'sindicacion:',
	'info_syndication_articles' => 'article(s)',
	'item_bloquer_liens_syndiques' => 'Blocar lu estacs sindicats per validacion',
	'item_gerer_annuaire_site_web' => 'Gerar un annuari de sits web',
	'item_non_bloquer_liens_syndiques' => 'Blocar pas lu ligams eissuts de la sindicacion',
	'item_non_gerer_annuaire_site_web' => 'Desactivar l’annuari de sits web',
	'item_non_utiliser_syndication' => 'Utilisar pas la sindicacion automatica',
	'item_utiliser_syndication' => 'Utilisar la sindicacion automatica',

	// L
	'lien_mise_a_jour_syndication' => 'Actualisar aüra',
	'lien_nouvelle_recuperation' => 'Temptar una novèla recuperacion de li donadas',

	// S
	'syndic_choix_moderation' => 'Que faire dei estacs venentsen provenença d’aquèu sit ?',
	'syndic_choix_oublier' => 'Que faire dei estacs que figuran pas plus dins lo fichièr de syndicacion ?',
	'syndic_choix_resume' => 'Certen sites difusan lo tèxt complet dei articles. Quora aqueste es disponible, desiratz de lo sindicar? :',
	'syndic_lien_obsolete' => 'Estac vielh',
	'syndic_option_miroir' => 'li blocar automaticament',
	'syndic_option_oubli' => 'li efaçar (après @mois@ mes)',
	'syndic_option_resume_non' => 'lo contengut complet dei articles (au format HTML)',
	'syndic_option_resume_oui' => 'un simple resumit (au format tèxte)',
	'syndic_options' => 'Opcions de syndicacion :',

	// T
	'texte_liens_sites_syndiques' => 'Lu ligams eissits dei sits sindicats si poadon
   blocar à priòri; lo reglatge
  çai sota indica lo reglatge predefinit dei
   sits sindicats après la sieu creacion. De tota maniera,
    es possible pi de 
   desblocar cada ligam individualament, ò de
   chausir, sit per sit, de blocar lu ligams avenidors
   de tau ò tau sit.', # MODIF
	'texte_messages_publics' => 'Messatges publics de l’article:',
	'texte_non_fonction_referencement' => 'Podètz chausir d’utilisar pas aquela foncion automatica, e indicar de vos meme lu elements que tòcan aqueu sit...', # MODIF
	'texte_referencement_automatique' => '<b>Referençament automatisat d’un sit</b><br />Podètz referençar leu un sit web en indicant çai sota l’adreça URL desirada, ò l’adreça dau sieu fichier de sindicacion. SPIP agantarà automaticament li informacions que concernisson aqueu sit (titre, descripcion...).', # MODIF
	'texte_syndication' => 'Si pòu recuperar automaticament, quora un sit web lo permet, 
  la tièra dei sieus noveutats. Per far aquò, vos cau activar la sindicacion. 
  <blockquote><i>D’unu aubergadors activon pas aquela foncionalitat; 
  dins aqueu cas, podretz pas utilisar la sindicacion de contengut
  despí lo voastre sit.</i></blockquote>', # MODIF
	'titre_articles_syndiques' => 'Articles sindicats tirats d’aqueu sit',
	'titre_dernier_article_syndique' => 'Darriers articles sindicats',
	'titre_page_sites_tous' => 'Lu sits referençats',
	'titre_referencement_sites' => 'Referençament de sits e sindicacion',
	'titre_site_numero' => 'SIT NÚMERO :',
	'titre_sites_proposes' => 'Lu sits prepauats',
	'titre_sites_references_rubrique' => 'Lu sits referençats dins aquela rubrica',
	'titre_sites_syndiques' => 'Lu sits sindicats',
	'titre_sites_tous' => 'Lu sits referençats',
	'titre_syndication' => 'Sindicacion dei sits'
);

?>
